import React, { memo, lazy, Suspense } from 'react';
import { Link } from 'react-router-dom';
import { Navbar } from '@/components/layout/navbar';
import { Footer } from '@/components/layout/footer';
import { Button } from '@/components/ui/button';
import { ChevronRight } from 'lucide-react';
import { Helmet } from 'react-helmet';
import { OrganizationSchema } from '@/components/seo/SchemaMarkup';
import { useAuth } from '@/contexts/AuthContext';

// Performance optimization: memoized components to prevent unnecessary re-renders
const MemoizedButton = memo(Button);

const Index = () => {
  const { user } = useAuth();
  
  return (
    <div className="min-h-screen flex flex-col">
      <Helmet>
        <title>Liberty Capital Immigration & Funding | Premium Immigration Financing</title>
        <meta name="description" content="Liberty Capital provides premium financing solutions for elite U.S. immigration programs, including EB-5, E-2, O-1 visas and the exclusive Trump Gold Card." />
        <meta name="keywords" content="immigration financing, visa funding, Trump Gold Card, EB-5 visa, E-2 visa, O-1 visa, US immigration" />
        <link rel="canonical" href="https://libertycapital.com/" />
      </Helmet>
      
      <OrganizationSchema
        url="https://libertycapital.com"
        name="Liberty Capital Immigration & Funding"
        logo="https://libertycapital.com/favicon.svg"
        description="Premium financing solutions for elite immigration programs"
      />
      
      <Navbar />
      
      {/* Hero Section - Critical for First Paint */}
      <div className="relative bg-white pt-20">
        <div className="absolute inset-0 bg-navy-50 h-[70vh]"></div>
        <div className="relative container mx-auto px-4 md:px-6 py-16 md:py-24 text-center">
          <h1 className="text-4xl md:text-6xl font-bold text-navy-800 mb-6">
            U.S. Immigration Through <span className="text-gold-600">Premium Financing</span>
          </h1>
          <p className="text-xl text-navy-600 max-w-3xl mx-auto mb-10">
            Liberty Capital provides premium financing solutions for elite U.S. immigration programs, including the exclusive Trump Gold Card.
          </p>
          <div className="flex flex-col sm:flex-row justify-center gap-4">
            {user ? (
              <Link to="/dashboard">
                <MemoizedButton size="lg" className="bg-navy-700 hover:bg-navy-800 text-white font-medium text-base px-8 rounded-md shadow-lg hover:shadow-xl transition-all">
                  Go to Dashboard <ChevronRight className="h-4 w-4 ml-1" />
                </MemoizedButton>
              </Link>
            ) : (
              <Link to="/auth">
                <MemoizedButton size="lg" className="bg-navy-700 hover:bg-navy-800 text-white font-medium text-base px-8 rounded-md shadow-lg hover:shadow-xl transition-all">
                  Get Started <ChevronRight className="h-4 w-4 ml-1" />
                </MemoizedButton>
              </Link>
            )}
            <Link to="/programs">
              <MemoizedButton size="lg" variant="outline" className="bg-white border-navy-200 text-navy-700 hover:bg-navy-50 font-medium text-base px-8 rounded-md">
                Explore Programs
              </MemoizedButton>
            </Link>
          </div>
        </div>
      </div>
      
      {/* Feature Section - Content that can be deferred */}
      <div className="bg-navy-50 py-20 md:py-28">
        <div className="container mx-auto px-4 md:px-6">
          <div className="text-center mb-16 pt-4">
            <h2 className="text-3xl md:text-4xl font-bold text-navy-800 mb-4">
              Why Choose Liberty Capital?
            </h2>
            <p className="text-lg text-navy-600 max-w-3xl mx-auto">
              We provide comprehensive financing solutions for your U.S. immigration journey, combining financial expertise with immigration knowledge.
            </p>
          </div>
          
          <div className="grid md:grid-cols-3 gap-8">
            {[
              {
                title: "Expert Advisory",
                description: "Our team of immigration and finance specialists provide personalized guidance throughout your journey."
              },
              {
                title: "Flexible Financing",
                description: "Customized financial solutions designed to meet the specific requirements of your chosen immigration pathway."
              },
              {
                title: "Streamlined Process",
                description: "A simplified application process with transparent terms and dedicated support at every step."
              }
            ].map((feature, index) => (
              <div key={index} className="bg-white rounded-lg p-8 shadow-md">
                <div className="h-12 w-12 rounded-full bg-navy-100 flex items-center justify-center mb-4">
                  <span className="text-navy-800 text-xl font-bold">{index + 1}</span>
                </div>
                <h3 className="text-xl font-semibold text-navy-800 mb-2">{feature.title}</h3>
                <p className="text-navy-600">{feature.description}</p>
              </div>
            ))}
          </div>
        </div>
      </div>
      
      {/* Programs Preview Section */}
      <div className="bg-white py-16 md:py-24">
        <div className="container mx-auto px-4 md:px-6">
          <div className="text-center mb-16">
            <h2 className="text-3xl md:text-4xl font-bold text-navy-800 mb-4">
              Our Immigration Programs
            </h2>
            <p className="text-lg text-navy-600 max-w-3xl mx-auto">
              Discover financing solutions for various U.S. immigration pathways tailored to your unique situation.
            </p>
          </div>
          
          <div className="grid md:grid-cols-2 lg:grid-cols-4 gap-6">
            {[
              {
                title: "Trump Gold Card",
                description: "Exclusive financing for premium visa categories",
                color: "bg-gold-600",
                link: "/programs/gold-card"
              },
              {
                title: "EB-5 Investor Visa",
                description: "Premium financing for investment-based immigration",
                color: "bg-navy-700",
                link: "/programs/eb5"
              },
              {
                title: "E-2 Treaty Investor",
                description: "Financing for business acquisition or startup",
                color: "bg-blue-600",
                link: "/programs/e2"
              },
              {
                title: "O-1 Extraordinary Ability",
                description: "Supporting distinguished talent in the U.S.",
                color: "bg-purple-600",
                link: "/programs/o1"
              }
            ].map((program, index) => (
              <div key={index} className="border border-navy-100 rounded-lg overflow-hidden shadow-md">
                <div className={`${program.color} text-white p-4`}>
                  <h3 className="text-xl font-semibold">{program.title}</h3>
                </div>
                <div className="p-4">
                  <p className="text-navy-600 mb-4">{program.description}</p>
                  <Link to={program.link}>
                    <MemoizedButton variant="outline" className="w-full border-navy-200">
                      Learn More
                    </MemoizedButton>
                  </Link>
                </div>
              </div>
            ))}
          </div>
          
          <div className="text-center mt-10">
            <Link to="/programs">
              <MemoizedButton className="bg-navy-700 text-white hover:bg-navy-800">
                View All Programs
              </MemoizedButton>
            </Link>
          </div>
        </div>
      </div>

      {/* Call to Action Section */}
      <div className="bg-navy-800 text-white py-16">
        <div className="container mx-auto px-4 md:px-6 text-center">
          <h2 className="text-3xl md:text-4xl font-bold mb-4">
            Ready to Start Your U.S. Immigration Journey?
          </h2>
          <p className="text-xl text-navy-100 max-w-3xl mx-auto mb-8">
            Take the first step toward your American dream with Liberty Capital's personalized financing solutions.
          </p>
          <div className="flex flex-col sm:flex-row justify-center gap-4">
            {user ? (
              <Link to="/dashboard">
                <MemoizedButton size="lg" className="bg-gold-500 hover:bg-gold-600 text-navy-900 font-medium">
                  Go to Dashboard
                </MemoizedButton>
              </Link>
            ) : (
              <Link to="/prequal">
                <MemoizedButton size="lg" className="bg-gold-500 hover:bg-gold-600 text-navy-900 font-medium">
                  Check Your Eligibility
                </MemoizedButton>
              </Link>
            )}
            <Link to="/contact">
              <MemoizedButton size="lg" variant="outline" className="border-navy-300 text-white hover:bg-navy-700 hover:border-white">
                Contact Our Team
              </MemoizedButton>
            </Link>
          </div>
        </div>
      </div>
      
      <Footer />
    </div>
  );
};

export default Index;
